.. module:: bana.OpenMaya.MPoint

.. _openmaya_mpoint:

OpenMaya.MPoint
===============

.. autosummary::
   :nosignatures:

   ~MPoint.__str__
   ~MPoint.bnGet


----

.. automethod:: MPoint.__str__

----

.. automethod:: MPoint.bnGet
